import type { InspectStVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  inspectStExport = '/eims/inspectSt/export',
  inspectStList = '/eims/inspectSt/list',
  root = '/eims/inspectSt'
}

/**
 * 查询点检汇总列表
 * @param query
 * @returns {*}
 */

export function listInspectSt(params?: any) {
  return requestClient.get<InspectStVO[]>(Api.inspectStList, { params });
}


/**
 * 查询点检汇总详细
 * @param inspectStId
 */
export function getInspectSt(inspectStId: ID) {
  return requestClient.get<InspectStVO>(`${Api.root}/${inspectStId}`);
}

/**
 * 新增点检汇总
 * @param data
 */
export function addInspectSt(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改点检汇总
 * @param data
 */
export function updateInspectSt(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除点检汇总
 * @param inspectStId
 */
export function delInspectSt(inspectStId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${inspectStId}`);
}
/**
 * 导出
 * @param
 */
export function inspectStExport(data: any) {
  return commonExport(Api.inspectStExport, data);
}
